@@ -5,7 +5,7 @@
 # (see spyderlib/__init__.py for details)
 
 """
-NumPy Array Editor Dialog based on PyQt4
+NumPy Array Editor Dialog based on Qt
 """
 
 # pylint: disable-msg=C0103
@@ -13,21 +13,22 @@ NumPy Array Editor Dialog based on PyQt4
 # pylint: disable-msg=R0911
 # pylint: disable-msg=R0201
 
-from PyQt4.QtCore import (Qt, QVariant, QModelIndex, QAbstractTableModel,
-                          SIGNAL, SLOT)
-from PyQt4.QtGui import (QHBoxLayout, QColor, QTableView, QItemDelegate,
-                         QLineEdit, QCheckBox, QGridLayout, QDoubleValidator,
-                         QDialog, QDialogButtonBox, QMessageBox, QPushButton,
-                         QInputDialog, QMenu, QApplication, QKeySequence,
-                         QLabel, QComboBox, QStackedWidget, QWidget,
-                         QVBoxLayout)
+from spyderlib.qt.QtGui import (QHBoxLayout, QColor, QTableView, QItemDelegate,
+                                QLineEdit, QCheckBox, QGridLayout,
+                                QDoubleValidator, QDialog, QDialogButtonBox,
+                                QMessageBox, QPushButton, QInputDialog, QMenu,
+                                QApplication, QKeySequence, QLabel, QComboBox,
+                                QStackedWidget, QWidget, QVBoxLayout)
+from spyderlib.qt.QtCore import (Qt, QVariant, QModelIndex,
+                                 QAbstractTableModel, SIGNAL, SLOT)
+
 import numpy as np
 import StringIO
 
 # Local imports
-from spyderlib.config import get_icon, get_font
-from spyderlib.utils.qthelpers import (translate, add_actions, create_action,
-                                       keybinding, qapplication)
+from spyderlib.config import get_icon, get_font, _
+from spyderlib.utils.qthelpers import (add_actions, create_action, keybinding,
+                                       qapplication)
 
 # Note: string and unicode data types will be formatted with '%s' (see below)
 SUPPORTED_FORMATS = {
@@ -88,12 +89,14 @@ def get_idx_rect(index_list):
 
 class ArrayModel(QAbstractTableModel):
     """Array Editor Table Model"""
-    def __init__(self, data, format="%.3f",
-                 xy_mode=False, readonly=False, parent=None):
+    def __init__(self, data, format="%.3f", xlabels=None, ylabels=None,
+                 readonly=False, parent=None):
         QAbstractTableModel.__init__(self)
 
         self.dialog = parent
         self.changes = {}
+        self.xlabels = xlabels
+        self.ylabels = ylabels
         self.readonly = readonly
         self.test_array = np.array([0], dtype=data.dtype)
 
@@ -112,7 +115,6 @@ class ArrayModel(QAbstractTableModel):
 
         self._data = data
         self._format = format
-        self._xy = xy_mode
         
         try:
             self.vmin = self.color_func(data).min()
@@ -236,18 +238,11 @@ class ArrayModel(QAbstractTableModel):
         """Set header data"""
         if role != Qt.DisplayRole:
             return QVariant()
-        if orientation == Qt.Horizontal:
+        labels = self.xlabels if orientation == Qt.Horizontal else self.ylabels
+        if labels is None:
             return QVariant(int(section))
         else:
-            if self._xy:
-                if section == 0:
-                    return QVariant('x')
-                elif self.rowCount() == 2:
-                    return QVariant('y')
-                else:
-                    return QVariant('y ('+str(section-1)+')')
-            else:
-                return QVariant(int(section))
+            return QVariant(labels[section])
 
 
 class ArrayDelegate(QItemDelegate):
@@ -306,13 +301,11 @@ class ArrayView(QTableView):
         for dim in self.shape:
             size *= dim
         if size > 1e5:
-            answer = QMessageBox.warning(self, translate("ArrayEditor",
-                                                         "Array editor"),
-                                translate("ArrayEditor",
-                                          "Resizing cells of a table of such "
-                                          "size could take a long time.\n"
-                                          "Do you want to continue anyway?"),
-                                QMessageBox.Yes | QMessageBox.No)
+            answer = QMessageBox.warning(self, _("Array editor"),
+                                         _("Resizing cells of a table of such "
+                                           "size could take a long time.\n"
+                                           "Do you want to continue anyway?"),
+                                         QMessageBox.Yes | QMessageBox.No)
             if answer == QMessageBox.No:
                 return
         self.resizeColumnsToContents()
@@ -320,8 +313,7 @@ class ArrayView(QTableView):
 
     def setup_menu(self):
         """Setup context menu"""
-        self.copy_action = create_action(self,
-                                         translate("ArrayEditor", "Copy"),
+        self.copy_action = create_action(self, _( "Copy"),
                                          shortcut=keybinding("Copy"),
                                          icon=get_icon('editcopy.png'),
                                          triggered=self.copy,
@@ -363,7 +355,8 @@ class ArrayView(QTableView):
 
 
 class ArrayEditorWidget(QWidget):
-    def __init__(self, parent, data, xy, readonly):
+    def __init__(self, parent, data, readonly=False,
+                 xlabels=None, ylabels=None):
         QWidget.__init__(self, parent)
         self.data = data
         self.old_data_shape = None
@@ -375,21 +368,21 @@ class ArrayEditorWidget(QWidget):
             self.data.shape = (1, 1)
 
         format = SUPPORTED_FORMATS.get(data.dtype.name, '%s')
-        self.model = ArrayModel(self.data, format=format,
-                                xy_mode=xy, readonly=readonly, parent=self)
+        self.model = ArrayModel(self.data, format=format, xlabels=xlabels,
+                                ylabels=ylabels, readonly=readonly, parent=self)
         self.view = ArrayView(self, self.model, data.dtype, data.shape)
         
         btn_layout = QHBoxLayout()
         btn_layout.setAlignment(Qt.AlignLeft)
-        btn = QPushButton(translate("ArrayEditor", "Format"))
+        btn = QPushButton(_( "Format"))
         # disable format button for int type
         btn.setEnabled(is_float(data.dtype))
         btn_layout.addWidget(btn)
         self.connect(btn, SIGNAL("clicked()"), self.change_format)
-        btn = QPushButton(translate("ArrayEditor", "Resize"))
+        btn = QPushButton(_( "Resize"))
         btn_layout.addWidget(btn)
         self.connect(btn, SIGNAL("clicked()"), self.view.resize_to_contents)
-        bgcolor = QCheckBox(translate("ArrayEditor", 'Background color'))
+        bgcolor = QCheckBox(_( 'Background color'))
         bgcolor.setChecked(self.model.bgcolor_enabled)
         bgcolor.setEnabled(self.model.bgcolor_enabled)
         self.connect(bgcolor, SIGNAL("stateChanged(int)"), self.model.bgcolor)
@@ -414,18 +407,16 @@ class ArrayEditorWidget(QWidget):
         
     def change_format(self):
         """Change display format"""
-        format, valid = QInputDialog.getText(self,
-                                 translate("ArrayEditor", 'Format'),
-                                 translate("ArrayEditor", "Float formatting"),
+        format, valid = QInputDialog.getText(self, _( 'Format'),
+                                 _( "Float formatting"),
                                  QLineEdit.Normal, self.model.get_format())
         if valid:
             format = str(format)
             try:
                 format % 1.1
             except:
-                QMessageBox.critical(self, translate("ArrayEditor", "Error"),
-                          translate("ArrayEditor",
-                                    "Format (%1) is incorrect").arg(format))
+                QMessageBox.critical(self, _("Error"),
+                                     _("Format (%s) is incorrect") % format)
                 return
             self.model.set_format(format)    
 
@@ -436,7 +427,8 @@ class ArrayEditor(QDialog):
         QDialog.__init__(self, parent)
         self.data = None
     
-    def setup_and_check(self, data, title='', xy=False, readonly=False):
+    def setup_and_check(self, data, title='', readonly=False,
+                        xlabels=None, ylabels=None):
         """
         Setup ArrayEditor:
         return False if data is not supported, True otherwise
@@ -445,27 +437,37 @@ class ArrayEditor(QDialog):
         self.arraywidget = None
         self.is_record_array = data.dtype.names is not None
         if data.size == 0:
-            self.error(self.tr("Array is empty"))
+            self.error(_("Array is empty"))
             return False
         if data.ndim > 2:
-            self.error(self.tr("Arrays with more than 2 dimensions "
+            self.error(_("Arrays with more than 2 dimensions "
                                "are not supported"))
             return False
+        if xlabels is not None and len(xlabels) != self.data.shape[1]:
+            self.error(_("The 'xlabels' argument length "
+						 	   "do no match array column number"))
+            return False
+        if ylabels is not None and len(ylabels) != self.data.shape[0]:
+            self.error(_("The 'ylabels' argument length "
+							   "do no match array row number"))
+            return False
         if not self.is_record_array:
             dtn = data.dtype.name
             if dtn not in SUPPORTED_FORMATS and not dtn.startswith('string') \
                and not dtn.startswith('unicode'):
-                arr = self.tr("%1 arrays").arg(data.dtype.name)
-                self.error(self.tr("%1 are currently not supported").arg(arr))
+                arr = _("%s arrays") % data.dtype.name
+                self.error(_("%s are currently not supported") % arr)
                 return False
         
         self.layout = QGridLayout()
         self.setLayout(self.layout)
         self.setWindowIcon(get_icon('arredit.png'))
-        if not title:
-            title = self.tr("Array editor")
+        if title:
+            title = unicode(title) # in case title is not a string
+        else:
+            title = _("Array editor")
         if readonly:
-            title += ' (' + self.tr('read only') + ')'
+            title += ' (' + _('read only') + ')'
         self.setWindowTitle(title)
         self.resize(600, 500)
         
@@ -474,9 +476,10 @@ class ArrayEditor(QDialog):
         if self.is_record_array:
             for name in data.dtype.names:
                 self.stack.addWidget(ArrayEditorWidget(self, data[name],
-                                                       xy, readonly))
+                                                   readonly, xlabels, ylabels))
         else:
-            self.stack.addWidget(ArrayEditorWidget(self, data, xy, readonly))
+            self.stack.addWidget(ArrayEditorWidget(self, data, readonly,
+                                                   xlabels, ylabels))
         self.arraywidget = self.stack.currentWidget()
         self.connect(self.stack, SIGNAL('currentChanged(int)'),
                      self.current_widget_changed)
@@ -485,7 +488,7 @@ class ArrayEditor(QDialog):
         # Buttons configuration
         btn_layout = QHBoxLayout()
         if self.is_record_array:
-            btn_layout.addWidget(QLabel(self.tr("Record array fields:")))
+            btn_layout.addWidget(QLabel(_("Record array fields:")))
             ra_combo = QComboBox(self)
             self.connect(ra_combo, SIGNAL('currentIndexChanged(int)'),
                          self.stack.setCurrentIndex)
@@ -530,7 +533,7 @@ class ArrayEditor(QDialog):
 
     def error(self, message):
         """An error occured, closing the dialog box"""
-        QMessageBox.critical(self, self.tr("Array editor"), message)
+        QMessageBox.critical(self, _("Array editor"), message)
         self.setAttribute(Qt.WA_DeleteOnClose)
         self.reject()
 
@@ -542,7 +545,8 @@ class ArrayEditor(QDialog):
         QDialog.reject(self)
     
     
-def aedit(data, title="", xy=False, readonly=False, parent=None):
+def aedit(data, title="", xlabels=None, ylabels=None,
+          readonly=False, parent=None):
     """
     Edit the array 'data' with the ArrayEditor and return the edited copy
     (if Cancel is pressed, return None)
@@ -551,7 +555,8 @@ def aedit(data, title="", xy=False, readonly=False, parent=None):
     """
     app = qapplication()
     dialog = ArrayEditor(parent)
-    if dialog.setup_and_check(data, title, xy=xy, readonly=readonly):
+    if dialog.setup_and_check(data, title, xlabels=xlabels, ylabels=ylabels,
+                              readonly=readonly):
         dialog.show()
         app.exec_()
         if dialog.result():
@@ -571,9 +576,10 @@ def test():
                    dtype=[(('title 1', 'x'), '|i1'), (('title 2', 'y'), '>f4')])
     print "out:", aedit(arr, "record array with titles")
     arr = np.random.rand(5, 5)
-    print "out:", aedit(arr, "float array")
+    print "out:", aedit(arr, "float array", xlabels=['a', 'b', 'c', 'd', 'e'])
     arr = np.round(np.random.rand(5, 5)*10)+np.round(np.random.rand(5, 5)*10)*1j
-    print "out:", aedit(arr, "complex array")
+    print "out:", aedit(arr, "complex array", xlabels=np.linspace(-12, 12, 5),
+                        ylabels=np.linspace(-12, 12, 5))
     arr_in = np.array([True, False, True])
     print "in:", arr_in
     arr_out = aedit(arr_in, "bool array")
