@@ -5,7 +5,7 @@
 # (see spyderlib/__init__.py for details)
 
 """
-Dictionary Editor Widget and Dialog based on PyQt4
+Dictionary Editor Widget and Dialog based on Qt
 """
 
 #TODO: Multiple selection: open as many editors (array/dict/...) as necessary,
@@ -17,18 +17,18 @@ Dictionary Editor Widget and Dialog based on PyQt4
 # pylint: disable-msg=R0201
 
 import re, os, sys
-from PyQt4.QtGui import (QMessageBox, QTableView, QItemDelegate, QLineEdit,
-                         QVBoxLayout, QWidget, QColor, QDialog, QDateEdit,
-                         QDialogButtonBox, QMenu, QInputDialog, QDateTimeEdit,
-                         QApplication, QKeySequence, QFileDialog)
-from PyQt4.QtCore import (Qt, QVariant, QModelIndex, QAbstractTableModel,
-                          SIGNAL, SLOT, QDateTime)
+from spyderlib.qt.QtGui import (QMessageBox, QTableView, QItemDelegate,
+                                QLineEdit, QVBoxLayout, QWidget, QColor,
+                                QDialog, QDateEdit, QDialogButtonBox, QMenu,
+                                QInputDialog, QDateTimeEdit, QApplication,
+                                QKeySequence, QFileDialog)
+from spyderlib.qt.QtCore import (Qt, QVariant, QModelIndex,
+                                 QAbstractTableModel, SIGNAL, SLOT, QDateTime)
 
 # Local import
-from spyderlib.config import get_icon, get_font
+from spyderlib.config import get_icon, get_font, _
 from spyderlib.utils import fix_reference_name
-from spyderlib.utils.qthelpers import (translate, add_actions, create_action,
-                                       qapplication)
+from spyderlib.utils.qthelpers import add_actions, create_action, qapplication
 from spyderlib.widgets.texteditor import TextEditor
 from spyderlib.widgets.importwizard import ImportWizard
 
@@ -142,6 +142,8 @@ def display_to_value(value, default_value, ignore_errors=True):
     try:
         if isinstance(default_value, str):
             value = str(value)
+        elif isinstance(default_value, unicode):
+            value = unicode(value)
         elif isinstance(default_value, float):
             value = float(value)
         elif isinstance(default_value, int):
@@ -190,7 +192,7 @@ def get_type(item):
     """Return type of an item"""
     text = get_type_string(item)
     if text is None:
-        text = unicode(translate('DictEditor', 'unknown'))
+        text = unicode(_('unknown'))
     return text[text.find('.')+1:]
 
 def is_known_type(item):
@@ -231,24 +233,23 @@ class ReadOnlyDictModel(QAbstractTableModel):
         if dictfilter is not None and not self.remote:
             data = dictfilter(data)
         self.showndata = data
-        self.header0 = translate("DictEditor", "Index")
+        self.header0 = _("Index")
         if self.names:
-            self.header0 = translate("DictEditor", "Name")
+            self.header0 = _("Name")
         if isinstance(data, tuple):
             self.keys = range(len(data))
-            self.title += translate("DictEditor", "Tuple")
+            self.title += _("Tuple")
         elif isinstance(data, list):
             self.keys = range(len(data))
-            self.title += translate("DictEditor", "List")
+            self.title += _("List")
         elif isinstance(data, dict):
             self.keys = data.keys()
-            self.title += translate("DictEditor", "Dictionary")
+            self.title += _("Dictionary")
             if not self.names:
-                self.header0 = translate("DictEditor", "Key")
+                self.header0 = _("Key")
         else:
             raise TypeError("Invalid data type")
-        self.title += ' ('+str(len(self.keys))+' '+ \
-                      translate("DictEditor", "elements")+')'
+        self.title += ' ('+str(len(self.keys))+' '+ _("elements")+')'
         if self.remote:
             self.sizes = [ data[self.keys[index]]['size']
                            for index in range(len(self.keys)) ]
@@ -370,10 +371,7 @@ class ReadOnlyDictModel(QAbstractTableModel):
                 return QVariant()
         i_column = int(section)
         if orientation == Qt.Horizontal:
-            headers = (self.header0,
-                       translate("DictEditor", "Type"),
-                       translate("DictEditor", "Size"),
-                       translate("DictEditor", "Value"))
+            headers = (self.header0, _("Type"), _("Size"), _("Value"))
             return QVariant( headers[i_column] )
         else:
             return QVariant()
@@ -447,20 +445,19 @@ class DictDelegate(QItemDelegate):
         try:
             value = self.get_value(index)
         except Exception, msg:
-            QMessageBox.critical(self.parent(),
-                                 translate("DictEditor", "Edit item"),
-                                 translate("DictEditor",
-                                           "<b>Unable to retrieve data.</b>"
-                                           "<br><br>Error message:<br>%1"
-                                           ).arg(unicode(msg)))
+            QMessageBox.critical(self.parent(), _("Edit item"),
+                                 _("<b>Unable to retrieve data.</b>"
+                                   "<br><br>Error message:<br>%s"
+                                   ) % unicode(msg))
             return
         key = index.model().get_key(index)
         readonly = isinstance(value, tuple) or self.parent().readonly \
                    or not is_known_type(value)
         #---editor = DictEditor
         if isinstance(value, (list, tuple, dict)) and not self.inplace:
-            editor = DictEditor(value, key, icon=self.parent().windowIcon(),
-                                readonly=readonly)
+            editor = DictEditor()
+            editor.setup(value, key, icon=self.parent().windowIcon(),
+                         readonly=readonly)
             self.create_dialog(editor, dict(model=index.model(), editor=editor,
                                             key=key, readonly=readonly))
             return None
@@ -586,11 +583,10 @@ class DictDelegate(QItemDelegate):
             value = display_to_value(QVariant(value), self.get_value(index),
                                      ignore_errors=False)
         except Exception, msg:
-            QMessageBox.critical(editor, translate("DictEditor", "Edit item"),
-                                 translate("DictEditor",
-                                       "<b>Unable to assign data to item.</b>"
-                                       "<br><br>Error message:<br>%1"
-                                       ).arg(str(msg)))
+            QMessageBox.critical(editor, _("Edit item"),
+                                 _("<b>Unable to assign data to item.</b>"
+                                   "<br><br>Error message:<br>%s"
+                                   ) % str(msg))
             return
         self.set_value(index, value)
 
@@ -634,76 +630,59 @@ class BaseTableView(QTableView):
             self.collvalue_action.setChecked(collvalue)
             return
         
-        self.empty_ws_menu = QMenu(self)
-        self.paste_action = create_action(self,
-                                      translate("DictEditor", "Paste"),
-                                      icon=get_icon('editpaste.png'),
-                                      triggered=self.paste)
-        self.empty_ws_menu.addAction(self.paste_action)
-        
-        self.copy_action = create_action(self,
-                                      translate("DictEditor", "Copy"),
-                                      icon=get_icon('editcopy.png'),
-                                      triggered=self.copy)                                      
-        self.edit_action = create_action(self, 
-                                      translate("DictEditor", "Edit"),
-                                      icon=get_icon('edit.png'),
-                                      triggered=self.edit_item)
-        self.plot_action = create_action(self, 
-                                      translate("DictEditor", "Plot"),
-                                      icon=get_icon('plot.png'),
-                                      triggered=self.plot_item)
+        self.paste_action = create_action(self, _("Paste"),
+                                          icon=get_icon('editpaste.png'),
+                                          triggered=self.paste)
+        self.copy_action = create_action(self, _("Copy"),
+                                         icon=get_icon('editcopy.png'),
+                                         triggered=self.copy)                                      
+        self.edit_action = create_action(self, _("Edit"),
+                                         icon=get_icon('edit.png'),
+                                         triggered=self.edit_item)
+        self.plot_action = create_action(self, _("Plot"),
+                                         icon=get_icon('plot.png'),
+                                         triggered=self.plot_item)
         self.plot_action.setVisible(False)
-        self.imshow_action = create_action(self, 
-                                      translate("DictEditor", "Show image"),
-                                      icon=get_icon('imshow.png'),
-                                      triggered=self.imshow_item)
+        self.imshow_action = create_action(self, _("Show image"),
+                                           icon=get_icon('imshow.png'),
+                                           triggered=self.imshow_item)
         self.imshow_action.setVisible(False)
-        self.save_array_action = create_action(self, 
-                                      translate("DictEditor", "Save array"),
-                                      icon=get_icon('filesave.png'),
-                                      triggered=self.save_array)
+        self.save_array_action = create_action(self, _("Save array"),
+                                               icon=get_icon('filesave.png'),
+                                               triggered=self.save_array)
         self.save_array_action.setVisible(False)
-        self.insert_action = create_action(self, 
-                                      translate("DictEditor", "Insert"),
-                                      icon=get_icon('insert.png'),
-                                      triggered=self.insert_item)
-        self.remove_action = create_action(self, 
-                                      translate("DictEditor", "Remove"),
-                                      icon=get_icon('editdelete.png'),
-                                      triggered=self.remove_item)
-        self.truncate_action = create_action(self,
-                                    translate("DictEditor", "Truncate values"),
-                                    toggled=self.toggle_truncate)
+        self.insert_action = create_action(self, _("Insert"),
+                                           icon=get_icon('insert.png'),
+                                           triggered=self.insert_item)
+        self.remove_action = create_action(self, _("Remove"),
+                                           icon=get_icon('editdelete.png'),
+                                           triggered=self.remove_item)
+        self.truncate_action = create_action(self, _("Truncate values"),
+                                             toggled=self.toggle_truncate)
         self.truncate_action.setChecked(truncate)
         self.toggle_truncate(truncate)
-        self.minmax_action = create_action(self,
-                                translate("DictEditor", "Show arrays min/max"),
-                                toggled=self.toggle_minmax)
+        self.minmax_action = create_action(self, _("Show arrays min/max"),
+                                           toggled=self.toggle_minmax)
         self.minmax_action.setChecked(minmax)
         self.toggle_minmax(minmax)
         self.collvalue_action = create_action(self,
-                            translate("DictEditor", "Show collection contents"),
-                            toggled=self.toggle_collvalue)
+                                              _("Show collection contents"),
+                                              toggled=self.toggle_collvalue)
         self.collvalue_action.setChecked(collvalue)
         self.toggle_collvalue(collvalue)
-        self.inplace_action = create_action(self,
-                                       translate("DictEditor",
-                                                 "Always edit in-place"),
-                                       toggled=self.toggle_inplace)
+        self.inplace_action = create_action(self, _("Always edit in-place"),
+                                            toggled=self.toggle_inplace)
         self.inplace_action.setChecked(inplace)
         if self.delegate is None:
             self.inplace_action.setEnabled(False)
         else:
             self.toggle_inplace(inplace)
-        self.rename_action = create_action(self,
-                                    translate("DictEditor", "Rename"),
-                                    icon=get_icon('rename.png'),
-                                    triggered=self.rename_item)
-        self.duplicate_action = create_action(self,
-                                    translate("DictEditor", "Duplicate"),
-                                    icon=get_icon('edit_add.png'),
-                                    triggered=self.duplicate_item)
+        self.rename_action = create_action(self, _( "Rename"),
+                                           icon=get_icon('rename.png'),
+                                           triggered=self.rename_item)
+        self.duplicate_action = create_action(self, _( "Duplicate"),
+                                              icon=get_icon('edit_add.png'),
+                                              triggered=self.duplicate_item)
         menu = QMenu(self)
         menu_actions = [self.edit_action, self.plot_action, self.imshow_action,
                         self.save_array_action, self.insert_action,
@@ -714,6 +693,8 @@ class BaseTableView(QTableView):
         if ndarray is not FakeObject:
             menu_actions.append(self.minmax_action)
         add_actions(menu, menu_actions)
+        self.empty_ws_menu = QMenu(self)
+        add_actions(self.empty_ws_menu, [self.insert_action, self.paste_action])
         return menu
     
     #------ Remote/local API ---------------------------------------------------
@@ -893,11 +874,9 @@ class BaseTableView(QTableView):
         for index in indexes:
             if not index.isValid():
                 return
-        one = translate("DictEditor", "Do you want to remove selected item?")
-        more = translate("DictEditor",
-                         "Do you want to remove all selected items?")
-        answer = QMessageBox.question(self,
-                                      translate("DictEditor", "Remove"),
+        one = _("Do you want to remove selected item?")
+        more = _("Do you want to remove all selected items?")
+        answer = QMessageBox.question(self, _( "Remove"),
                                       one if len(indexes) == 1 else more,
                                       QMessageBox.Yes | QMessageBox.No)
         if answer == QMessageBox.Yes:
@@ -914,10 +893,8 @@ class BaseTableView(QTableView):
         if len(idx_rows) > 1 or not indexes[0].isValid():
             return
         orig_key = self.model.keys[idx_rows[0]]
-        new_key, valid = QInputDialog.getText(self,
-                          translate("DictEditor", 'Rename'),
-                          translate("DictEditor", 'Key:'),
-                          QLineEdit.Normal,orig_key)
+        new_key, valid = QInputDialog.getText(self, _( 'Rename'), _( 'Key:'),
+                                              QLineEdit.Normal,orig_key)
         if valid and not new_key.isEmpty():
             new_key = try_to_eval(unicode(new_key))
             if new_key == orig_key:
@@ -946,20 +923,16 @@ class BaseTableView(QTableView):
             key = row
             data.insert(row, '')
         elif isinstance(data, dict):
-            key, valid = QInputDialog.getText(self,
-                              translate("DictEditor", 'Insert'),
-                              translate("DictEditor", 'Key:'),
-                              QLineEdit.Normal)
+            key, valid = QInputDialog.getText(self, _( 'Insert'), _( 'Key:'),
+                                              QLineEdit.Normal)
             if valid and not key.isEmpty():
                 key = try_to_eval(unicode(key))
             else:
                 return
         else:
             return
-        value, valid = QInputDialog.getText(self,
-                  translate("DictEditor", 'Insert'),
-                  translate("DictEditor", 'Value:'),
-                  QLineEdit.Normal)
+        value, valid = QInputDialog.getText(self, _('Insert'), _('Value:'),
+                                            QLineEdit.Normal)
         if valid and not value.isEmpty():
             self.new_value(key, try_to_eval(unicode(value)))
             
@@ -975,10 +948,9 @@ class BaseTableView(QTableView):
                     mpl_patch.apply()
                 return True
             except ImportError:
-                QMessageBox.warning(self, translate("DictEditor", "Import error"),
-                                    translate("DictEditor"
-                                              "Please install <b>matplotlib</b>"
-                                              " or <b>guiqwt</b>."))
+                QMessageBox.warning(self, _("Import error"),
+                                    _("Please install <b>matplotlib</b>"
+                                      " or <b>guiqwt</b>."))
 
     def plot_item(self):
         """Plot item"""
@@ -988,9 +960,10 @@ class BaseTableView(QTableView):
             try:
                 self.plot(key)
             except ValueError, error:
-                QMessageBox.critical(self, translate("DictEditor", "Plot"),
-                    translate("DictEditor", "<b>Unable to plot data.</b>"
-                              "<br><br>Error message:<br>%1").arg(str(error)))
+                QMessageBox.critical(self, _( "Plot"),
+                                     _("<b>Unable to plot data.</b>"
+                                       "<br><br>Error message:<br>%s"
+                                       ) % str(error))
             
     def imshow_item(self):
         """Imshow item"""
@@ -1003,18 +976,19 @@ class BaseTableView(QTableView):
                 else:
                     self.imshow(key)
             except ValueError, error:
-                QMessageBox.critical(self, translate("DictEditor", "Plot"),
-                    translate("DictEditor", "<b>Unable to show image.</b>"
-                              "<br><br>Error message:<br>%1").arg(str(error)))
+                QMessageBox.critical(self, _( "Plot"),
+                                     _("<b>Unable to show image.</b>"
+                                       "<br><br>Error message:<br>%s"
+                                       ) % str(error))
             
     def save_array(self):
         """Save array"""
-        title = translate("DictEditor", "Save array")
+        title = _( "Save array")
         if self.array_filename is None:
             self.array_filename = os.getcwdu()
         self.emit(SIGNAL('redirect_stdio(bool)'), False)
         filename = QFileDialog.getSaveFileName(self, title, self.array_filename,
-                          translate('DictEditor', "NumPy arrays")+" (*.npy)")
+                          _("NumPy arrays")+" (*.npy)")
         self.emit(SIGNAL('redirect_stdio(bool)'), True)
         if filename:
             self.array_filename = unicode(filename)
@@ -1024,8 +998,9 @@ class BaseTableView(QTableView):
                 np.save(self.array_filename, data)
             except Exception, error:
                 QMessageBox.critical(self, title,
-                     translate('DictEditor', "<b>Unable to save array</b>"
-                               "<br><br>Error message:<br>%1").arg(str(error)))
+                                     _("<b>Unable to save array</b>"
+                                       "<br><br>Error message:<br>%s"
+                                       ) % str(error))
     def copy(self):
         """Copy text to clipboard"""
         clipboard = QApplication.clipboard()
@@ -1040,8 +1015,7 @@ class BaseTableView(QTableView):
         """Import data from string"""
         data = self.model.get_data()
         editor = ImportWizard(self, text, title=title,
-                              contents_title=translate("DictEditor",
-                                                       "Clipboard contents"),
+                              contents_title=_("Clipboard contents"),
                               varname=fix_reference_name("data",
                                                          blacklist=data.keys()))
         if editor.exec_():
@@ -1055,14 +1029,10 @@ class BaseTableView(QTableView):
         if clipboard.mimeData().hasText():
             cliptext = unicode(clipboard.text())
         if cliptext.strip():
-            self.import_from_string(cliptext,
-                                    title=translate("DictEditor",
-                                                    "Import from clipboard"))
+            self.import_from_string(cliptext, title=_("Import from clipboard"))
         else:
-            QMessageBox.warning(self,
-                                translate("DictEditor", "Empty clipboard"),
-                                translate("DictEditor", "Nothing to be imported"
-                                          " from clipboard."))
+            QMessageBox.warning(self, _( "Empty clipboard"),
+                                _("Nothing to be imported from clipboard."))
         
 
 class DictEditorTableView(BaseTableView):
@@ -1206,9 +1176,13 @@ class DictEditorWidget(QWidget):
 
 class DictEditor(QDialog):
     """Dictionary/List Editor Dialog"""
-    def __init__(self, data, title="", width=500,
-                 readonly=False, icon='dictedit.png', remote=False):
-        QDialog.__init__(self)
+    def __init__(self, parent=None):
+        QDialog.__init__(self, parent)
+        self.data_copy = None
+        self.widget = None
+        
+    def setup(self, data, title='', readonly=False, width=500,
+              icon='dictedit.png', remote=False, parent=None):
         if isinstance(data, dict):
             # dictionnary
             self.data_copy = data.copy()
@@ -1261,7 +1235,8 @@ def dedit(seq):
     so it can be called directly from the interpreter)
     """
     app = qapplication()
-    dialog = DictEditor(seq)
+    dialog = DictEditor()
+    dialog.setup(seq)
     dialog.show()
     app.exec_()
     if dialog.result():
@@ -1343,9 +1318,8 @@ class RemoteDictEditorTableView(BaseTableView):
             return
         
         self.remote_editing_action = create_action(self,
-                translate("DictEditor", "Edit data in the remote process"),
-                tip=translate("DictEditor",
-                      "Editors are opened in the remote process for NumPy "
+                _( "Edit data in the remote process"),
+                tip=_("Editors are opened in the remote process for NumPy "
                       "arrays, PIL images, lists, tuples and dictionaries.\n"
                       "This avoids transfering large amount of data between "
                       "the remote process and Spyder (through the socket)."),
@@ -1439,6 +1413,7 @@ def get_test_data():
             'datetime': datetime.datetime(1945, 5, 8),
             'unsupported1': np.arccos,
             'unsupported2': np.cast,
+            1: (1, 2, 3), -5: ("a", "b", "c"), 2.5: np.array((4.0, 6.0, 8.0)),            
             }
 
 def test():
