@@ -11,13 +11,15 @@
 # pylint: disable-msg=R0911
 # pylint: disable-msg=R0201
 
-from PyQt4.QtGui import (QVBoxLayout, QFileDialog, QMessageBox, QMenu, QFont,
-                         QAction, QApplication, QWidget, QHBoxLayout, QLabel,
-                         QKeySequence, QShortcut, QMainWindow, QSplitter,
-                         QListWidget, QListWidgetItem, QDialog, QLineEdit, 
-                         QIntValidator, QDialogButtonBox, QGridLayout)
-from PyQt4.QtCore import (SIGNAL, Qt, QFileInfo, QThread, QObject, QByteArray,
-                          PYQT_VERSION_STR, QSize, QPoint, SLOT, QTimer)
+from spyderlib.qt.QtGui import (QVBoxLayout, QFileDialog, QMessageBox, QMenu,
+                                QFont, QAction, QApplication, QWidget,
+                                QHBoxLayout, QLabel, QKeySequence, QShortcut,
+                                QMainWindow, QSplitter, QListWidget,
+                                QListWidgetItem, QDialog, QLineEdit, 
+                                QIntValidator, QDialogButtonBox, QGridLayout)
+from spyderlib.qt.QtCore import (SIGNAL, Qt, QFileInfo, QThread, QObject,
+                                 QByteArray, PYQT_VERSION_STR, QSize, QPoint,
+                                 SLOT, QTimer)
 
 import os, sys, re
 import os.path as osp
@@ -27,18 +29,18 @@ STDOUT = sys.stdout
 DEBUG = False
 
 # Local imports
-from spyderlib.utils import encoding, sourcecode
-from spyderlib.config import get_icon, get_font
+from spyderlib.utils import encoding, sourcecode, programs
+from spyderlib.config import get_icon, get_font, _
 from spyderlib.utils.qthelpers import (create_action, add_actions, mimedata2url,
-                                       get_filetype_icon, translate,
-                                       create_toolbutton)
+                                       get_filetype_icon, create_toolbutton)
 from spyderlib.widgets.tabs import BaseTabs
 from spyderlib.widgets.findreplace import FindReplace
 from spyderlib.widgets.editortools import OutlineExplorer, check
-from spyderlib.widgets.codeeditor import syntaxhighlighters
-from spyderlib.widgets.codeeditor.base import TextEditBaseWidget #@UnusedImport
-from spyderlib.widgets.codeeditor.codeeditor import CodeEditor, get_primary_at
-from spyderlib.widgets.codeeditor.codeeditor import Printer #@UnusedImport
+from spyderlib.widgets.sourcecode import syntaxhighlighters
+from spyderlib.widgets.sourcecode.base import TextEditBaseWidget #@UnusedImport
+from spyderlib.widgets.sourcecode.codeeditor import CodeEditor, get_primary_at
+from spyderlib.widgets.sourcecode.codeeditor import Printer #@UnusedImport
+from spyderlib.widgets.sourcecode.codeeditor import get_file_language
 
 
 class GoToLineDialog(QDialog):
@@ -46,17 +48,17 @@ class GoToLineDialog(QDialog):
         QDialog.__init__(self, editor)
         self.editor = editor
         
-        self.setWindowTitle(translate("Editor", "Editor"))
+        self.setWindowTitle(_("Editor"))
         self.setModal(True)
         
-        label = QLabel(translate("Editor", "Go to line:"))
+        label = QLabel(_("Go to line:"))
         self.lineedit = QLineEdit()
         validator = QIntValidator(self.lineedit)
         validator.setRange(1, editor.get_line_count())
         self.lineedit.setValidator(validator)        
-        cl_label = QLabel(translate("Editor", "Current line:"))
+        cl_label = QLabel(_("Current line:"))
         cl_label_v = QLabel("<b>%d</b>" % editor.get_cursor_line_number())
-        last_label = QLabel(translate("Editor", "Line count:"))
+        last_label = QLabel(_("Line count:"))
         last_label_v = QLabel("%d" % editor.get_line_count())
         
         glayout = QGridLayout()
@@ -98,16 +100,16 @@ class FileListDialog(QDialog):
         self.indexes = None
         
         self.setWindowIcon(get_icon('filelist.png'))
-        self.setWindowTitle(translate("Editor", "File list management"))
+        self.setWindowTitle(_("File list management"))
         
         self.setModal(True)
         
-        flabel = QLabel(translate("Editor", "Filter:"))
+        flabel = QLabel(_("Filter:"))
         self.edit = QLineEdit(self)
         self.connect(self.edit, SIGNAL("returnPressed()"), self.edit_file)
         self.connect(self.edit, SIGNAL("textChanged(QString)"),
                      lambda text: self.synchronize(0))
-        fhint = QLabel(translate("Editor", "(press <b>Enter</b> to edit file)"))
+        fhint = QLabel(_("(press <b>Enter</b> to edit file)"))
         edit_layout = QHBoxLayout()
         edit_layout.addWidget(flabel)
         edit_layout.addWidget(self.edit)
@@ -117,10 +119,12 @@ class FileListDialog(QDialog):
         self.listwidget.setResizeMode(QListWidget.Adjust)
         self.connect(self.listwidget, SIGNAL("itemSelectionChanged()"),
                      self.item_selection_changed)
+        self.connect(self.listwidget, SIGNAL("itemActivated(QListWidgetItem*)"),
+                     self.edit_file)
         
         btn_layout = QHBoxLayout()
         edit_btn = create_toolbutton(self, icon=get_icon('edit.png'),
-                     text=translate("Editor", "&Edit file"), autoraise=False,
+                     text=_("&Edit file"), autoraise=False,
                      triggered=self.edit_file, text_beside_icon=True)
         edit_btn.setMinimumHeight(28)
         btn_layout.addWidget(edit_btn)
@@ -129,8 +133,7 @@ class FileListDialog(QDialog):
         btn_layout.addSpacing(150)
         btn_layout.addStretch()
         
-        close_btn = create_toolbutton(self,
-              text=translate("Editor", "&Close file"),
+        close_btn = create_toolbutton(self, text=_("&Close file"),
               icon=get_icon("fileclose.png"),
               autoraise=False, text_beside_icon=True,
               triggered=lambda: self.emit(SIGNAL("close_file(int)"),
@@ -138,8 +141,7 @@ class FileListDialog(QDialog):
         close_btn.setMinimumHeight(28)
         btn_layout.addWidget(close_btn)
 
-        hint = QLabel(translate("Editor",
-                             "Hint: press <b>Alt</b> to show accelerators"))
+        hint = QLabel(_("Hint: press <b>Alt</b> to show accelerators"))
         hint.setAlignment(Qt.AlignCenter)
         
         vlayout = QVBoxLayout()
@@ -298,6 +300,7 @@ class FileInfo(QObject):
             return []
         source_code = unicode(self.editor.toPlainText())
         offset = self.editor.get_position('cursor')
+        
         textlist = self.project.get_completion_list(source_code, offset,
                                                     self.filename)
         if textlist:
@@ -311,6 +314,7 @@ class FileInfo(QObject):
             return
         source_code = unicode(self.editor.toPlainText())
         offset = position
+        
         textlist = self.project.get_calltip_text(source_code, offset,
                                                  self.filename)
         text = ''
@@ -321,9 +325,14 @@ class FileInfo(QObject):
         if not text:
             text = get_primary_at(source_code, offset)
         if text and not text.startswith('self.'):
-            self.emit(SIGNAL("send_to_inspector(QString)"), text)
+            doc_text = ''
+            if len(textlist) == 2:
+                doc_text = textlist.pop(1)
+            if doc_text:
+                self.emit(SIGNAL("send_to_inspector(QString,QString,bool)"),
+                          text, doc_text, True)
         if textlist:
-            self.editor.show_calltip("rope", textlist)
+            self.editor.show_calltip("rope", textlist, at_position=position)
                     
     def go_to_definition(self, position):
         if self.project is None:
@@ -380,24 +389,6 @@ class FileInfo(QObject):
                   self.filename, repr(breakpoints))
 
 
-def get_file_language(filename, text=None):
-    ext = osp.splitext(filename)[1]
-    if ext.startswith('.'):
-        ext = ext[1:] # file extension with leading dot
-    language = ext
-    if not ext:
-        if text is None:
-            text, _enc = encoding.read(filename)
-        for line in text.splitlines():
-            if not line.strip():
-                continue
-            if line.startswith('#!') and \
-               line[2:].split() == ['/usr/bin/env', 'python']:
-                    language = 'python'
-            else:
-                break
-    return language
-        
 class EditorStack(QWidget):
     def __init__(self, parent, plugin, actions):
         QWidget.__init__(self, parent)
@@ -429,12 +420,10 @@ class EditorStack(QWidget):
 
         self.data = []
         
-        filelist_action = create_action(self,
-                                 translate("Editor", "File list management"),
+        filelist_action = create_action(self, _("File list management"),
                                  icon=get_icon('filelist.png'),
                                  triggered=self.open_filelistdialog)
-        copy_to_cb_action = create_action(self,
-                translate("Editor", "Copy path to clipboard"),
+        copy_to_cb_action = create_action(self, _("Copy path to clipboard"),
                 icon="editcopy.png",
                 triggered=lambda:
                 QApplication.clipboard().setText(self.get_current_filename()))
@@ -449,7 +438,7 @@ class EditorStack(QWidget):
         self.save_action = None
         self.revert_action = None
         self.tempfile_path = None
-        self.title = translate("Editor", "Editor")
+        self.title = _("Editor")
         self.filetype_filters = None
         self.valid_types = None
         self.codeanalysis_enabled = True
@@ -544,7 +533,7 @@ class EditorStack(QWidget):
     def setup_editorstack(self, parent, layout):
         """Setup editorstack's layout"""
         menu_btn = create_toolbutton(self, icon=get_icon("tooloptions.png"),
-                                     tip=translate("Editor", "Options"))
+                                     tip=_("Options"))
         self.menu = QMenu(self)
         menu_btn.setMenu(self.menu)
         menu_btn.setPopupMode(menu_btn.InstantPopup)
@@ -552,17 +541,17 @@ class EditorStack(QWidget):
 
 #        self.filelist_btn = create_toolbutton(self,
 #                             icon=get_icon('filelist.png'),
-#                             tip=translate("Editor", "File list management"),
+#                             tip=_("File list management"),
 #                             triggered=self.open_filelistdialog)
 #        
 #        self.previous_btn = create_toolbutton(self,
 #                             icon=get_icon('previous.png'),
-#                             tip=translate("Editor", "Previous file"),
+#                             tip=_("Previous file"),
 #                             triggered=self.go_to_previous_file)
 #        
 #        self.next_btn = create_toolbutton(self,
 #                             icon=get_icon('next.png'),
-#                             tip=translate("Editor", "Next file"),
+#                             tip=_("Next file"),
 #                             triggered=self.go_to_next_file)
                 
         # Optional tabs
@@ -588,16 +577,22 @@ class EditorStack(QWidget):
         QWidget.closeEvent(self, event)
         if PYQT_VERSION_STR.startswith('4.6'):
             self.emit(SIGNAL('destroyed()'))        
+    
+    def clone_editor_from(self, other_finfo, set_current):
+        fname = other_finfo.filename
+        enc = other_finfo.encoding
+        new = other_finfo.newly_created
+        finfo = self.create_new_editor(fname, enc, "",
+                                       set_current=set_current, new=new,
+                                       cloned_from=other_finfo.editor)
+        finfo.set_analysis_results(other_finfo.analysis_results)
+        finfo.set_todo_results(other_finfo.todo_results)
+        return finfo.editor
             
     def clone_from(self, other):
         """Clone EditorStack from other instance"""
         for other_finfo in other.data:
-            fname = other_finfo.filename
-            enc = other_finfo.encoding
-            finfo = self.create_new_editor(fname, enc, "", set_current=True,
-                                           cloned_from=other_finfo.editor)
-            finfo.set_analysis_results(other_finfo.analysis_results)
-            finfo.set_todo_results(other_finfo.todo_results)
+            self.clone_editor_from(other_finfo, set_current=True)
         self.set_stack_index(other.get_stack_index())
         
     def open_filelistdialog(self):
@@ -637,9 +632,14 @@ class EditorStack(QWidget):
             
     def inspect_current_object(self):
         """Inspect current object in Object Inspector"""
-        text = self.get_current_editor().get_current_object()
-        if text:
-            self.send_to_inspector(text)
+        if programs.is_module_installed('rope'):
+            editor = self.get_current_editor()
+            position = editor.get_position('cursor')
+            editor.emit(SIGNAL('trigger_calltip(int)'), position)
+        else:
+            text = self.get_current_editor().get_current_object()
+            if text:
+                self.send_to_inspector(text, force=True)
         
         
     #------ Editor Widget Settings
@@ -891,6 +891,38 @@ class EditorStack(QWidget):
         self.update_actions()
         self.update_filelistdialog()
     
+    def __modified_readonly_title(self, title, is_modified, is_readonly):
+        if is_modified is not None and is_modified:
+            title += "*"
+        if is_readonly is not None and is_readonly:
+            title = "(%s)" % title
+        return title
+    
+    def get_tab_text(self, filename, is_modified=None, is_readonly=None):
+        """Return tab title"""
+        return self.__modified_readonly_title(osp.basename(filename),
+                                              is_modified, is_readonly)
+                
+    def get_tab_tip(self, filename, is_modified=None, is_readonly=None):
+        """Return tab menu title"""
+        if self.fullpath_sorting_enabled:
+            text = filename
+        else:
+            text = u"%s — %s"
+        text = self.__modified_readonly_title(text,
+                                              is_modified, is_readonly)
+        if filename == encoding.to_unicode(self.tempfile_path):
+            temp_file_str = unicode(_("Temporary file"))
+            if self.fullpath_sorting_enabled:
+                return "%s (%s)" % (text, temp_file_str)
+            else:
+                return text % (temp_file_str, self.tempfile_path)
+        else:
+            if self.fullpath_sorting_enabled:
+                return text
+            else:
+                return text % (osp.basename(filename), osp.dirname(filename))
+        
     def __get_sorting_func(self):
         if self.fullpath_sorting_enabled:
             return lambda item: osp.join(osp.dirname(item.filename),
@@ -905,6 +937,7 @@ class EditorStack(QWidget):
         fname, editor = finfo.filename, finfo.editor
         self.tabs.insertTab(index, editor, get_filetype_icon(fname),
                             self.get_tab_text(fname))
+        self.set_stack_title(index, False)
         if set_current:
             self.set_stack_index(index)
         if set_current:
@@ -917,8 +950,10 @@ class EditorStack(QWidget):
         self.tabs.clear()
         for finfo in self.data:
             icon = get_filetype_icon(finfo.filename)
-            self.tabs.addTab(finfo.editor, icon,
-                             self.get_tab_text(finfo.filename))
+            tab_text = self.get_tab_text(finfo.filename)
+            tab_tip = self.get_tab_tip(finfo.filename)
+            index = self.tabs.addTab(finfo.editor, icon, tab_text)
+            self.tabs.setTabToolTip(index, tab_tip)
         self.tabs.blockSignals(False)
         self.update_filelistdialog()
         
@@ -939,7 +974,12 @@ class EditorStack(QWidget):
             self.outlineexplorer.file_renamed(finfo.editor, finfo.filename)
         return new_index
         
-    def set_stack_title(self, index, tab_text, tab_tip):
+    def set_stack_title(self, index, is_modified):
+        finfo = self.data[index]
+        fname = finfo.filename
+        is_readonly = finfo.editor.isReadOnly()
+        tab_text = self.get_tab_text(fname, is_modified, is_readonly)
+        tab_tip = self.get_tab_tip(fname, is_modified, is_readonly)
         self.tabs.setTabText(index, tab_text)
         self.tabs.setTabToolTip(index, tab_tip)
         
@@ -960,28 +1000,20 @@ class EditorStack(QWidget):
     #------ Hor/Ver splitting
     def __get_split_actions(self):
         # New window
-        self.newwindow_action = create_action(self,
-                    translate("Editor", "New window"),
-                    icon="newwindow.png",
-                    tip=translate("Editor", "Create a new editor window"),
+        self.newwindow_action = create_action(self, _("New window"),
+                    icon="newwindow.png", tip=_("Create a new editor window"),
                     triggered=lambda: self.emit(SIGNAL("create_new_window()")))
         # Splitting
-        self.versplit_action = create_action(self,
-                    translate("Editor", "Split vertically"),
+        self.versplit_action = create_action(self, _("Split vertically"),
                     icon="versplit.png",
-                    tip=translate("Editor",
-                                  "Split vertically this editor window"),
+                    tip=_("Split vertically this editor window"),
                     triggered=lambda: self.emit(SIGNAL("split_vertically()")))
-        self.horsplit_action = create_action(self,
-                    translate("Editor", "Split horizontally"),
+        self.horsplit_action = create_action(self, _("Split horizontally"),
                     icon="horsplit.png",
-                    tip=translate("Editor",
-                                  "Split horizontally this editor window"),
+                    tip=_("Split horizontally this editor window"),
                     triggered=lambda: self.emit(SIGNAL("split_horizontally()")))
-        self.close_action = create_action(self,
-                    translate("Editor", "Close this panel"),
-                    icon="close_panel.png",
-                    triggered=self.close)
+        self.close_action = create_action(self, _("Close this panel"),
+                    icon="close_panel.png", triggered=self.close)
         return [None, self.newwindow_action, None, 
                 self.versplit_action, self.horsplit_action, self.close_action]
         
@@ -1028,7 +1060,7 @@ class EditorStack(QWidget):
 
         
     #------ Close file, tabwidget...
-    def close_file(self, index=None):
+    def close_file(self, index=None, force=False):
         """
         Close file (index=None -> close current file)
         Keep current file index unchanged (if current file that is being closed)
@@ -1047,7 +1079,7 @@ class EditorStack(QWidget):
                 new_index = self._get_previous_file_index()
             else:
                 new_index = current_index
-        is_ok = self.save_if_changed(cancelable=True, index=index)
+        is_ok = force or self.save_if_changed(cancelable=True, index=index)
         if is_ok:
             finfo = self.data[index]
             finfo.close_threads()
@@ -1065,6 +1097,7 @@ class EditorStack(QWidget):
             self.emit(SIGNAL('update_code_analysis_actions()'))
             self._refresh_outlineexplorer()
             self.emit(SIGNAL('refresh_file_dependent_actions()'))
+            self.emit(SIGNAL('update_plugin_title()'))
             
             if new_index is not None:
                 if index < new_index:
@@ -1106,10 +1139,10 @@ class EditorStack(QWidget):
                     return False
             elif finfo.editor.document().isModified():
                 answer = QMessageBox.question(self, self.title,
-                            translate("Editor",
-                                      "<b>%1</b> has been modified."
-                                      "<br>Do you want to save changes?").arg(
-                            osp.basename(finfo.filename)), buttons)
+                            _("<b>%s</b> has been modified."
+                              "<br>Do you want to save changes?"
+                              ) % osp.basename(finfo.filename),
+                            buttons)
                 if answer == QMessageBox.Yes:
                     if not self.save(refresh_explorer=False):
                         return False
@@ -1163,11 +1196,11 @@ class EditorStack(QWidget):
                           osp.dirname(finfo.filename))
             return True
         except EnvironmentError, error:
-            QMessageBox.critical(self, translate("Editor", "Save"),
-                            translate("Editor",
-                                      "<b>Unable to save script '%1'</b>"
-                                      "<br><br>Error message:<br>%2").arg(
-                            osp.basename(finfo.filename)).arg(str(error)))
+            QMessageBox.critical(self, _("Save"),
+                                 _("<b>Unable to save script '%s'</b>"
+                                   "<br><br>Error message:<br>%s"
+                                   ) % (osp.basename(finfo.filename),
+                                        str(error)))
             return False
         
     def file_saved_in_other_editorstack(self, index):
@@ -1181,8 +1214,7 @@ class EditorStack(QWidget):
     
     def select_savename(self, original_filename):
         self.emit(SIGNAL('redirect_stdio(bool)'), False)
-        filename = QFileDialog.getSaveFileName(self,
-                                   translate("Editor", "Save Python script"),
+        filename = QFileDialog.getSaveFileName(self, _("Save Python script"),
                                    original_filename, self.filetype_filters)
         self.emit(SIGNAL('redirect_stdio(bool)'), True)
         if filename:
@@ -1287,6 +1319,7 @@ class EditorStack(QWidget):
             print >>STDOUT, "current_changed:", index, self.data[index].editor,
             print >>STDOUT, self.data[index].editor.get_document_id()
             
+        self.emit(SIGNAL('update_plugin_title()'))
         if editor is not None:
             self.emit(SIGNAL('current_file_changed(QString,int)'),
                       self.data[index].filename, editor.get_position('cursor'))
@@ -1385,12 +1418,11 @@ class EditorStack(QWidget):
         # First, testing if file still exists (removed, moved or offline):
         if not osp.isfile(finfo.filename):
             answer = QMessageBox.warning(self, self.title,
-                            translate("Editor",
-                                      "<b>%1</b> is unavailable "
-                                      "(this file may have been removed, moved "
-                                      "or renamed outside Spyder)."
-                                      "<br>Do you want to close it?").arg(name),
-                            QMessageBox.Yes | QMessageBox.No)
+                                _("<b>%s</b> is unavailable "
+                                  "(this file may have been removed, moved "
+                                  "or renamed outside Spyder)."
+                                  "<br>Do you want to close it?") % name,
+                                QMessageBox.Yes | QMessageBox.No)
             if answer == QMessageBox.Yes:
                 self.close_file(index)
         else:
@@ -1399,12 +1431,11 @@ class EditorStack(QWidget):
             if lastm.toString().compare(finfo.lastmodified.toString()):
                 if finfo.editor.document().isModified():
                     answer = QMessageBox.question(self,
-                        self.title,
-                        translate("Editor",
-                                  "<b>%1</b> has been modified outside Spyder."
+                                self.title,
+                                _("<b>%s</b> has been modified outside Spyder."
                                   "<br>Do you want to reload it and loose all "
-                                  "your changes?").arg(name),
-                        QMessageBox.Yes | QMessageBox.No)
+                                  "your changes?") % name,
+                                QMessageBox.Yes | QMessageBox.No)
                     if answer == QMessageBox.Yes:
                         self.reload(index)
                     else:
@@ -1430,6 +1461,7 @@ class EditorStack(QWidget):
             self.__refresh_statusbar(index)
             self.__refresh_readonly(index)
             self.__check_file_status(index)
+            self.emit(SIGNAL('update_plugin_title()'))
         else:
             editor = None
         # Update the modification-state-dependent parameters
@@ -1437,46 +1469,6 @@ class EditorStack(QWidget):
         # Update FindReplace binding
         self.find_widget.set_editor(editor, refresh=False)
                 
-    def __modified_readonly_title(self, title, is_modified, is_readonly):
-        if is_modified is not None and is_modified:
-            title += "*"
-        if is_readonly is not None and is_readonly:
-            title = "(%s)" % title
-        return title
-    
-    def get_tab_text(self, filename, is_modified=None, is_readonly=None):
-        """Return tab title"""
-        return self.__modified_readonly_title(osp.basename(filename),
-                                              is_modified, is_readonly)
-                
-    def get_tab_tip(self, filename, is_modified=None, is_readonly=None):
-        """Return tab menu title"""
-        if self.fullpath_sorting_enabled:
-            text = filename
-        else:
-            text = u"%s — %s"
-        text = self.__modified_readonly_title(text,
-                                              is_modified, is_readonly)
-        if filename == encoding.to_unicode(self.tempfile_path):
-            temp_file_str = unicode(translate("Editor", "Temporary file"))
-            if self.fullpath_sorting_enabled:
-                return "%s (%s)" % (text, temp_file_str)
-            else:
-                return text % (temp_file_str, self.tempfile_path)
-        else:
-            if self.fullpath_sorting_enabled:
-                return text
-            else:
-                return text % (osp.basename(filename), osp.dirname(filename))
-        
-    def get_titles(self, is_modified, finfo):
-        """Return tab text and tool tip"""
-        fname = finfo.filename
-        is_readonly = finfo.editor.isReadOnly()
-        tab_text = self.get_tab_text(fname, is_modified, is_readonly)
-        tab_tip = self.get_tab_tip(fname, is_modified, is_readonly)
-        return tab_text, tab_tip
-    
     def modification_changed(self, state=None, index=None):
         """
         Current editor's modification state has changed
@@ -1499,8 +1491,7 @@ class EditorStack(QWidget):
         finfo = self.data[index]
         if state is None:
             state = finfo.editor.document().isModified()
-        tab_text, tab_tip = self.get_titles(state, finfo)
-        self.set_stack_title(index, tab_text, tab_tip)
+        self.set_stack_title(index, state)
         # Toggle save/save all actions state
         self.save_action.setEnabled(state)
         self.revert_action.setEnabled(state)
@@ -1508,7 +1499,7 @@ class EditorStack(QWidget):
         # Refreshing eol mode
         eol_chars = finfo.editor.get_line_separator()
         os_name = sourcecode.get_os_name_from_eol_chars(eol_chars)
-        self.emit(SIGNAL('refresh_eol_mode(QString)'), os_name)
+        self.emit(SIGNAL('refresh_eol_chars(QString)'), os_name)
         
 
     #------ Load, reload
@@ -1526,10 +1517,10 @@ class EditorStack(QWidget):
         index = self.get_stack_index()
         filename = self.data[index].filename
         answer = QMessageBox.warning(self, self.title,
-                    translate("Editor",
-                              "All changes to <b>%1</b> will be lost."
-                              "<br>Do you want to revert file from disk?").arg(
-                    osp.basename(filename)), QMessageBox.Yes|QMessageBox.No)
+                                _("All changes to <b>%s</b> will be lost."
+                                  "<br>Do you want to revert file from disk?"
+                                  ) % osp.basename(filename),
+                                  QMessageBox.Yes|QMessageBox.No)
         if answer == QMessageBox.Yes:
             self.reload(index)
         
@@ -1544,7 +1535,7 @@ class EditorStack(QWidget):
         if self.projectexplorer is not None:
             finfo.set_project(self.projectexplorer.get_source_project(fname))
         self.add_to_data(finfo, set_current)
-        self.connect(finfo, SIGNAL("send_to_inspector(QString)"),
+        self.connect(finfo, SIGNAL("send_to_inspector(QString,QString,bool)"),
                      self.send_to_inspector)
         self.connect(finfo, SIGNAL('analysis_results_changed()'),
                      lambda: self.emit(SIGNAL('analysis_results_changed()')))
@@ -1604,16 +1595,20 @@ class EditorStack(QWidget):
         self.find_widget.set_editor(editor)
        
         self.emit(SIGNAL('refresh_file_dependent_actions()'))
-        self.modification_changed()
+        self.modification_changed(index=self.data.index(finfo))
         
         return finfo
     
-    def send_to_inspector(self, qstr):
-        if not self.inspector_enabled:
+    def send_to_inspector(self, qstr1, qstr2=None, force=False):
+        """qstr1: obj_text, qstr2: doc_text"""
+        if not force and not self.inspector_enabled:
             return
         if self.inspector is not None and self.inspector.dockwidget.isVisible():
             # ObjectInspector widget exists and is visible
-            self.inspector.set_object_text(qstr, ignore_unknown=True)
+            if qstr2 is None:
+                self.inspector.set_object_text(qstr1, ignore_unknown=True)
+            else:
+                self.inspector.set_rope_doc(unicode(qstr1), unicode(qstr2))
             editor = self.get_current_editor()
             editor.setFocus()
     
@@ -1636,7 +1631,7 @@ class EditorStack(QWidget):
         """
         filename = osp.abspath(unicode(filename))
         self.emit(SIGNAL('starting_long_process(QString)'),
-                  translate("Editor", "Loading %1...").arg(filename))
+                  _("Loading %s...") % filename)
         text, enc = encoding.read(filename)
         finfo = self.create_new_editor(filename, enc, text, set_current)
         index = self.get_stack_index()
@@ -1646,11 +1641,10 @@ class EditorStack(QWidget):
            and sourcecode.has_mixed_eol_chars(text):
             name = osp.basename(filename)
             QMessageBox.warning(self, self.title,
-                            translate("Editor",
-                                      "<b>%1</b> contains mixed end-of-line "
-                                      "characters.<br>Spyder will fix this "
-                                      "automatically.").arg(name),
-                            QMessageBox.Ok)
+                                _("<b>%s</b> contains mixed end-of-line "
+                                  "characters.<br>Spyder will fix this "
+                                  "automatically.") % name,
+                                QMessageBox.Ok)
             self.set_os_eol_chars(index)
         self.is_analysis_done = False
         return finfo.editor
@@ -1659,8 +1653,8 @@ class EditorStack(QWidget):
         if index is None:
             index = self.get_stack_index()
         finfo = self.data[index]
-        eol_mode = sourcecode.get_eol_chars_from_os_name(os.name)
-        finfo.editor.set_eol_mode(eol_mode)
+        eol_chars = sourcecode.get_eol_chars_from_os_name(os.name)
+        finfo.editor.set_eol_chars(eol_chars)
         finfo.editor.document().setModified(True)
         
     def remove_trailing_spaces(self, index=None):
@@ -1922,7 +1916,7 @@ class ReadWriteStatus(StatusBarWidget):
     def __init__(self, parent, statusbar):
         StatusBarWidget.__init__(self, parent, statusbar)
         layout = self.layout()
-        layout.addWidget(QLabel(translate("Editor", "Permissions:")))
+        layout.addWidget(QLabel(_("Permissions:")))
         self.readwrite = QLabel()
         self.readwrite.setFont(self.label_font)
         layout.addWidget(self.readwrite)
@@ -1937,7 +1931,7 @@ class EOLStatus(StatusBarWidget):
     def __init__(self, parent, statusbar):
         StatusBarWidget.__init__(self, parent, statusbar)
         layout = self.layout()
-        layout.addWidget(QLabel(translate("Editor", "End-of-lines:")))
+        layout.addWidget(QLabel(_("End-of-lines:")))
         self.eol = QLabel()
         self.eol.setFont(self.label_font)
         layout.addWidget(self.eol)
@@ -1952,7 +1946,7 @@ class EncodingStatus(StatusBarWidget):
     def __init__(self, parent, statusbar):
         StatusBarWidget.__init__(self, parent, statusbar)
         layout = self.layout()
-        layout.addWidget(QLabel(translate("Editor", "Encoding:")))
+        layout.addWidget(QLabel(_("Encoding:")))
         self.encoding = QLabel()
         self.encoding.setFont(self.label_font)
         layout.addWidget(self.encoding)
@@ -1966,11 +1960,11 @@ class CursorPositionStatus(StatusBarWidget):
     def __init__(self, parent, statusbar):
         StatusBarWidget.__init__(self, parent, statusbar)
         layout = self.layout()
-        layout.addWidget(QLabel(translate("Editor", "Line:")))
+        layout.addWidget(QLabel(_("Line:")))
         self.line = QLabel()
         self.line.setFont(self.label_font)
         layout.addWidget(self.line)
-        layout.addWidget(QLabel(translate("Editor", "Column:")))
+        layout.addWidget(QLabel(_("Column:")))
         self.column = QLabel()
         self.column.setFont(self.label_font)
         layout.addWidget(self.column)
@@ -2006,7 +2000,10 @@ class EditorWidget(QSplitter):
                                             show_all_files=show_all_files,
                                             show_comments=show_comments)
         self.connect(self.outlineexplorer,
-                     SIGNAL("edit_goto(QString,int,QString)"), plugin.load)
+                     SIGNAL("edit_goto(QString,int,QString)"),
+                     lambda filenames, goto, word:
+                     plugin.load(filenames=filenames, goto=goto, word=word,
+                                 editorwindow=self.parent()))
         
         editor_widgets = QWidget(self)
         editor_layout = QVBoxLayout()
@@ -2035,6 +2032,7 @@ class EditorWidget(QSplitter):
         if DEBUG:
             print >>STDOUT, "EditorWidget.register_editorstack:", editorstack
             self.__print_editorstacks()
+        self.plugin.last_focus_editorstack[self.parent()] = editorstack
         editorstack.set_closable( len(self.editorstacks) > 1 )
         editorstack.set_outlineexplorer(self.outlineexplorer)
         editorstack.set_find_widget(self.find_widget)
@@ -2050,7 +2048,7 @@ class EditorWidget(QSplitter):
                      self.encoding_status.encoding_changed)
         self.connect(editorstack, SIGNAL('cursorPositionChanged(int,int)'),
                      self.cursorpos_status.cursor_position_changed)
-        self.connect(editorstack, SIGNAL('refresh_eol_mode(QString)'),
+        self.connect(editorstack, SIGNAL('refresh_eol_chars(QString)'),
                      self.eol_status.eol_changed)
         self.plugin.register_editorstack(editorstack)
         oe_btn = create_toolbutton(self)
@@ -2103,11 +2101,10 @@ class EditorMainWindow(QMainWindow):
                 add_actions(toolbar, actions)
                 toolbars.append(toolbar)
         if menu_list:
-            quit_action = create_action(self,
-                                translate("Editor", "Close window"),
-                                icon="close_panel.png",
-                                tip=translate("Editor", "Close this window"),
-                                triggered=self.close)
+            quit_action = create_action(self, _("Close window"),
+                                        icon="close_panel.png",
+                                        tip=_("Close this window"),
+                                        triggered=self.close)
             menus = []
             for index, (title, actions) in enumerate(menu_list):
                 menu = self.menuBar().addMenu(title)
