@@ -13,23 +13,24 @@
 
 import sys, os, time, os.path as osp, re
 
-from PyQt4.QtGui import (QMenu, QApplication, QCursor, QToolTip, QKeySequence,
-                         QFileDialog, QMessageBox, QMouseEvent, QTextCursor,
-                         QTextCharFormat, QShortcut)
-from PyQt4.QtCore import Qt, QString, QCoreApplication, SIGNAL, pyqtProperty
+from spyderlib.qt.QtGui import (QMenu, QApplication, QCursor, QToolTip,
+                                QKeySequence, QFileDialog, QMessageBox,
+                                QMouseEvent, QTextCursor, QTextCharFormat,
+                                QShortcut)
+from spyderlib.qt.QtCore import (Qt, QString, QCoreApplication, SIGNAL,
+                                 pyqtProperty)
 
 # For debugging purpose:
 STDOUT = sys.stdout
 STDERR = sys.stderr
 
 # Local import
-from spyderlib import __version__
-from spyderlib.config import CONF, get_icon, get_conf_path
+from spyderlib.config import CONF, get_icon, get_conf_path, get_font, _
 from spyderlib.utils import encoding, get_error_match
 from spyderlib.utils.dochelpers import getobj
 from spyderlib.utils.qthelpers import (keybinding, create_action, add_actions,
-                                       restore_keyevent, translate)
-from spyderlib.widgets.codeeditor.base import ConsoleBaseWidget
+                                       restore_keyevent)
+from spyderlib.widgets.sourcecode.base import ConsoleBaseWidget
 
 
 HISTORY_FILENAMES = []
@@ -80,6 +81,16 @@ class ShellBaseWidget(ConsoleBaseWidget):
         # Give focus to widget
         self.setFocus()
                 
+        # Calltips
+        calltip_size = CONF.get('shell_appearance', 'calltips/size')
+        calltip_font = get_font('shell_appearance', 'calltips')
+        self.setup_calltips(calltip_size, calltip_font)
+        
+        # Completion
+        completion_size = CONF.get('shell_appearance', 'completion/size')
+        completion_font = get_font('shell_appearance', 'completion')
+        self.completion_widget.setup_appearance(completion_size,
+                                                completion_font)
         # Cursor width
         self.setCursorWidth( CONF.get('shell_appearance', 'cursor/width') )
         
@@ -102,36 +113,28 @@ class ShellBaseWidget(ConsoleBaseWidget):
     def setup_context_menu(self):
         """Setup shell context menu"""
         self.menu = QMenu(self)
-        self.cut_action = create_action(self,
-                                        translate("ShellBaseWidget", "Cut"),
+        self.cut_action = create_action(self, _("Cut"),
                                         shortcut=keybinding('Cut'),
                                         icon=get_icon('editcut.png'),
                                         triggered=self.cut)
-        self.copy_action = create_action(self,
-                                         translate("ShellBaseWidget", "Copy"),
+        self.copy_action = create_action(self, _("Copy"),
                                          shortcut=keybinding('Copy'),
                                          icon=get_icon('editcopy.png'),
                                          triggered=self.copy)
-        paste_action = create_action(self,
-                                     translate("ShellBaseWidget", "Paste"),
+        paste_action = create_action(self, _("Paste"),
                                      shortcut=keybinding('Paste'),
                                      icon=get_icon('editpaste.png'),
                                      triggered=self.paste)
-        save_action = create_action(self,
-                                    translate("ShellBaseWidget",
-                                              "Save history log..."),
+        save_action = create_action(self, _("Save history log..."),
                                     icon=get_icon('filesave.png'),
-                                    tip=translate("ShellBaseWidget",
-                                          "Save current history log (i.e. all "
+                                    tip=_("Save current history log (i.e. all "
                                           "inputs and outputs) in a text file"),
                                     triggered=self.save_historylog)
-        self.delete_action = create_action(self,
-                                    translate("ShellBaseWidget", "Delete"),
+        self.delete_action = create_action(self, _("Delete"),
                                     shortcut=keybinding('Delete'),
                                     icon=get_icon('editdelete.png'),
                                     triggered=self.delete)
-        selectall_action = create_action(self,
-                                    translate("ShellBaseWidget", "Select All"),
+        selectall_action = create_action(self, _("Select All"),
                                     shortcut=keybinding('SelectAll'),
                                     icon=get_icon('selectall.png'),
                                     triggered=self.selectAll)
@@ -241,7 +244,7 @@ class ShellBaseWidget(ConsoleBaseWidget):
         
     def save_historylog(self):
         """Save current history log (all text in console)"""
-        title = translate("ShellBaseWidget", "Save history log")
+        title = _("Save history log")
         self.emit(SIGNAL('redirect_stdio(bool)'), False)
         filename = QFileDialog.getSaveFileName(self, title,
                             self.historylog_filename, "History logs (*.log)")
@@ -254,10 +257,10 @@ class ShellBaseWidget(ConsoleBaseWidget):
                 CONF.set('main', 'historylog_filename', filename)
             except EnvironmentError, error:
                 QMessageBox.critical(self, title,
-                                translate("ShellBaseWidget",
-                                          "<b>Unable to save file '%1'</b>"
-                                          "<br><br>Error message:<br>%2") \
-                                .arg(osp.basename(filename)).arg(str(error)))
+                                     _("<b>Unable to save file '%s'</b>"
+                                       "<br><br>Error message:<br>%s"
+                                       ) % (osp.basename(filename),
+                                            str(error)))
         
         
     #------ Basic keypress event handler
@@ -333,6 +336,9 @@ class ShellBaseWidget(ConsoleBaseWidget):
                 self.insert_text(self.get_selected_text(), at_end=True)
             event.accept()
             
+        elif key == Qt.Key_Insert and not shift and not ctrl:
+            self.setOverwriteMode(not self.overwriteMode())
+            
         elif key == Qt.Key_Delete:
             if self.has_selected_text():
                 self.check_selection()
@@ -492,7 +498,7 @@ class ShellBaseWidget(ConsoleBaseWidget):
             rawhistory, _ = encoding.readlines(self.history_filename)
             rawhistory = [line.replace('\n', '') for line in rawhistory]
             if rawhistory[1] != self.INITHISTORY[1]:
-                rawhistory = self.INITHISTORY
+                rawhistory[1] = self.INITHISTORY[1]
         else:
             rawhistory = self.INITHISTORY
         history = [line for line in rawhistory \
@@ -665,7 +671,7 @@ class ShellBaseWidget(ConsoleBaseWidget):
     def dropEvent(self, event):
         """Drag and Drop - Drop event"""
         if (event.mimeData().hasFormat("text/plain")):
-            text = event.mimeData().text()
+            text = unicode(event.mimeData().text())
             if self.new_input_line:
                 self.on_new_line()
             self.insert_text(text, at_end=True)
@@ -685,7 +691,7 @@ class PythonShellWidget(ShellBaseWidget):
     Python shell widget
     """
     INITHISTORY = ['# -*- coding: utf-8 -*-',
-                   '# *** Spyder v%s -- History log ***' % __version__,]
+                   '# *** Spyder Python Console History Log ***',]
     SEPARATOR = '%s##---(%s)---' % (os.linesep*2, time.ctime())
     
     def __init__(self, parent, history_filename, debug=False, profile=False):
@@ -723,24 +729,18 @@ class PythonShellWidget(ShellBaseWidget):
         """Reimplements ShellBaseWidget method"""
         ShellBaseWidget.setup_context_menu(self)
         self.copy_without_prompts_action = create_action(self,
-                                     translate("PythonShellWidget",
-                                               "Copy without prompts"),
+                                     _("Copy without prompts"),
                                      icon=get_icon('copywop.png'),
                                      triggered=self.copy_without_prompts)
-        clear_line_action = create_action(self, translate("PythonShellWidget",
-                                                          "Clear line"),
-                                     QKeySequence("Escape"),
+        clear_line_action = create_action(self, _("Clear line"),
+                                     QKeySequence("Shift+Escape"),
                                      icon=get_icon('eraser.png'),
-                                     tip=translate("PythonShellWidget",
-                                                   "Clear line"),
+                                     tip=_("Clear line"),
                                      triggered=self.clear_line)
-        clear_action = create_action(self,
-                                     translate("PythonShellWidget",
-                                               "Clear shell"),
+        clear_action = create_action(self, _("Clear shell"),
                                      icon=get_icon('clear.png'),
-                                     tip=translate("PythonShellWidget",
-                                                   "Clear shell contents "
-                                                 "('cls' command)"),
+                                     tip=_("Clear shell contents "
+                                           "('cls' command)"),
                                      triggered=self.clear_terminal)
         add_actions(self.menu, (self.copy_without_prompts_action,
                     clear_line_action, clear_action))
@@ -862,7 +862,9 @@ class PythonShellWidget(ShellBaseWidget):
     def _key_question(self, text):
         """Action for '?'"""
         if self.get_current_line_to_cursor():
-            self.show_docstring(self.get_last_obj())
+            last_obj = self.get_last_obj()
+            if last_obj and not last_obj.isdigit():
+                self.show_docstring(last_obj)
         self.insert_text(text)
         # In case calltip and completion are shown at the same time:
         if self.is_completion_widget_visible():
@@ -872,7 +874,9 @@ class PythonShellWidget(ShellBaseWidget):
         """Action for '('"""
         self.hide_completion_widget()
         if self.get_current_line_to_cursor():
-            self.show_docstring(self.get_last_obj(), call=True)
+            last_obj = self.get_last_obj()
+            if last_obj and not last_obj.isdigit():
+                self.show_docstring(last_obj, call=True)
         self.insert_text(text)
         
     def _key_period(self, text):
@@ -891,6 +895,8 @@ class PythonShellWidget(ShellBaseWidget):
         text = unicode(QApplication.clipboard().text())
         if len(text.splitlines()) > 1:
             # Multiline paste
+            if self.new_input_line:
+                self.on_new_line()
             self.remove_selected_text() # Remove selection, eventually
             end = self.get_current_line_from_cursor()
             lines = self.get_current_line_to_cursor() + text + end
@@ -1009,11 +1015,15 @@ class PythonShellWidget(ShellBaseWidget):
                                       automatic=automatic)
             return
     
-    def show_docstring(self, text, call=False):
+    def show_docstring(self, text, call=False, force=False):
         """Show docstring or arguments"""
         text = unicode(text) # Useful only for ExternalShellBase
         
-        if self.inspector_enabled and (self.inspector is not None) and \
+        insp_enabled = self.inspector_enabled or force
+        if force and self.inspector is not None:
+            self.inspector.dockwidget.setVisible(True)
+            self.inspector.dockwidget.raise_()
+        if insp_enabled and (self.inspector is not None) and \
            (self.inspector.dockwidget.isVisible()):
             # ObjectInspector widget exists and is visible
             self.inspector.set_shell(self)
@@ -1031,14 +1041,12 @@ class PythonShellWidget(ShellBaseWidget):
                         if isinstance(arglist, bool):
                             arglist = []
                         if arglist:
-                            self.show_calltip(translate("PythonShellWidget",
-                                                        "Arguments"),
+                            self.show_calltip(_("Arguments"),
                                               arglist, '#129625')
         elif self.calltips: # inspector is not visible or link is disabled
             doc = self.get__doc__(text)
             if doc is not None:
-                self.show_calltip(translate("PythonShellWidget",
-                                            "Documentation"), doc)
+                self.show_calltip(_("Documentation"), doc)
         
         
     #------ Miscellanous
@@ -1067,7 +1075,7 @@ class PythonShellWidget(ShellBaseWidget):
         if tl2 and text2.startswith(tl2[0]):
             text += tl2[0]
         if text:
-            self.show_docstring(text)
+            self.show_docstring(text, force=True)
             
     #------ Drag'n Drop
     def drop_pathlist(self, pathlist):
@@ -1089,8 +1097,7 @@ class TerminalWidget(ShellBaseWidget):
     Terminal widget
     """
     COM = 'rem' if os.name == 'nt' else '#'
-    INITHISTORY = ['%s *** Spyder v%s -- History log ***' % (COM, __version__),
-                   COM,]
+    INITHISTORY = ['%s *** Spyder Terminal History Log ***' % COM, COM,]
     SEPARATOR = '%s%s ---(%s)---' % (os.linesep*2, COM, time.ctime())
     
     def __init__(self, parent, history_filename, debug=False, profile=False):
